@@ -32,16 +32,11 @@ function failure {
 rm -f logs/pids.txt logs/*.log
 
 start=`date`
-for os in `cat os-list.txt`; do
-  echo "Building $os"
-  ( cd $os && docker build -t "orc-$os" . ) > logs/$os-build.log 2>&1 || exit 1
-done
-testStart=`date`
 
-for os in `cat os-list.txt`; do
-    ./run-one.sh $1 $2 $os > logs/$os-test.log 2>&1 &
+for build in `cat os-list.txt`; do
+    ./run-one.sh $1 $2 $build > logs/$build-test.log 2>&1 &
     echo "$!" >> logs/pids.txt
-    echo "Launching $os as $!"
+    echo "Launching $build as $!"
 done
 
 for job in `cat logs/pids.txt`; do
@@ -50,6 +45,5 @@ for job in `cat logs/pids.txt`; do
 done
 
 echo ""
-echo "Build start: $start"
-echo "Test start: $testStart"
+echo "Test start: $start"
 echo "End:" `date`
