@@ -30,11 +30,17 @@ import org.apache.orc.ColumnStatistics;
 import org.apache.orc.DateColumnStatistics;
 import org.apache.orc.DecimalColumnStatistics;
 import org.apache.orc.DoubleColumnStatistics;
+import org.apache.orc.GeospatialColumnStatistics;
 import org.apache.orc.IntegerColumnStatistics;
 import org.apache.orc.OrcProto;
 import org.apache.orc.StringColumnStatistics;
 import org.apache.orc.TimestampColumnStatistics;
 import org.apache.orc.TypeDescription;
+import org.apache.orc.geospatial.BoundingBox;
+import org.apache.orc.geospatial.GeospatialTypes;
+import org.locationtech.jts.geom.Geometry;
+import org.locationtech.jts.io.ParseException;
+import org.locationtech.jts.io.WKBReader;
 import org.threeten.extra.chrono.HybridChronology;
 
 import java.sql.Date;
@@ -42,6 +48,11 @@ import java.sql.Timestamp;
 import java.time.chrono.ChronoLocalDate;
 import java.time.chrono.Chronology;
 import java.time.chrono.IsoChronology;
+import java.util.ArrayList;
+import java.util.Collections;
+import java.util.HashSet;
+import java.util.List;
+import java.util.Set;
 import java.util.TimeZone;
 
 
@@ -1858,6 +1869,167 @@ public class ColumnStatisticsImpl implements ColumnStatistics {
   private boolean hasNull = false;
   private long bytesOnDisk = 0;
 
+  private static final class GeospatialStatisticsImpl extends ColumnStatisticsImpl
+          implements GeospatialColumnStatistics {
+    private final BoundingBox boundingBox;
+    private final GeospatialTypes geospatialTypes;
+    private final WKBReader reader = new WKBReader();
+
+    GeospatialStatisticsImpl() {
+      this.boundingBox = new BoundingBox();
+      this.geospatialTypes = new GeospatialTypes();
+    }
+
+    GeospatialStatisticsImpl(OrcProto.ColumnStatistics stats) {
+      super(stats);
+      BoundingBox boundingBoxOut = null;
+      GeospatialTypes geospatialTypesOut = null;
+
+      OrcProto.GeospatialStatistics geoStatistics = stats.getGeospatialStatistics();
+      if (geoStatistics.hasBbox()) {
+        OrcProto.BoundingBox bbox = geoStatistics.getBbox();
+        boundingBoxOut = new BoundingBox(
+                bbox.hasXmin() ? bbox.getXmin() : Double.NaN,
+                bbox.hasXmax() ? bbox.getXmax() : Double.NaN,
+                bbox.hasYmin() ? bbox.getYmin() : Double.NaN,
+                bbox.hasYmax() ? bbox.getYmax() : Double.NaN,
+                bbox.hasZmin() ? bbox.getZmin() : Double.NaN,
+                bbox.hasZmax() ? bbox.getZmax() : Double.NaN,
+                bbox.hasMmin() ? bbox.getMmin() : Double.NaN,
+                bbox.hasMmax() ? bbox.getMmax() : Double.NaN);
+      }
+
+      if (!geoStatistics.getGeospatialTypesList().isEmpty()) {
+        Set<Integer> types = new HashSet<>(geoStatistics.getGeospatialTypesList());
+        geospatialTypesOut = new GeospatialTypes(types);
+      }
+      this.boundingBox = boundingBoxOut;
+      this.geospatialTypes = geospatialTypesOut;
+    }
+
+    @Override
+    public void updateGeometry(BytesWritable value) {
+      if (value == null) {
+        return;
+      }
+
+      try {
+        Geometry geom = reader.read(value.getBytes());
+        boundingBox.update(geom);
+        geospatialTypes.update(geom);
+      } catch (ParseException e) {
+        throw new IllegalArgumentException("Invalid geospatial data - failed to parse WKB format", e);
+      }
+    }
+
+    @Override
+    public void updateGeometry(byte[] bytes, int offset, int length) {
+      if (bytes == null) {
+        return;
+      }
+      BytesWritable value = new BytesWritable();
+      value.set(bytes, offset, length);
+      updateGeometry(value);
+    }
+
+    @Override
+    public void reset() {
+      super.reset();
+      boundingBox.reset();;
+      geospatialTypes.reset();
+    }
+
+    @Override
+    public void merge(ColumnStatisticsImpl other) {
+      if (other instanceof GeospatialStatisticsImpl geoStats) {
+        boundingBox.merge(geoStats.boundingBox);
+        geospatialTypes.merge(geoStats.geospatialTypes);
+      } else {
+        throw new IllegalArgumentException("Incompatible merging of geospatial column statistics");
+      }
+      super.merge(other);
+    }
+
+    @Override
+    public OrcProto.ColumnStatistics.Builder serialize() {
+      OrcProto.ColumnStatistics.Builder builder = super.serialize();
+      OrcProto.GeospatialStatistics.Builder geoStats = OrcProto.GeospatialStatistics.newBuilder();
+
+      OrcProto.BoundingBox.Builder bboxBuilder = OrcProto.BoundingBox.newBuilder();
+      if (boundingBox.isValid() && !boundingBox.isXYEmpty()) {
+        bboxBuilder.setXmin(boundingBox.getXMin());
+        bboxBuilder.setXmax(boundingBox.getXMax());
+        bboxBuilder.setYmin(boundingBox.getYMin());
+        bboxBuilder.setYmax(boundingBox.getYMax());
+        if (boundingBox.isZValid() && !boundingBox.isZEmpty()) {
+          bboxBuilder.setZmin(boundingBox.getZMin());
+          bboxBuilder.setZmax(boundingBox.getZMax());
+        }
+        if (boundingBox.isMValid() && !boundingBox.isMEmpty()) {
+          bboxBuilder.setMmin(boundingBox.getMMin());
+          bboxBuilder.setMmax(boundingBox.getMMax());
+        }
+        geoStats.setBbox(bboxBuilder);
+      }
+      if (geospatialTypes.isValid() && !geospatialTypes.getTypes().isEmpty()) {
+        List<Integer> sortedTypes = new ArrayList<>(geospatialTypes.getTypes());
+        Collections.sort(sortedTypes);
+        geoStats.addAllGeospatialTypes(sortedTypes);
+      }
+      builder.setGeospatialStatistics(geoStats);
+      return builder;
+    }
+
+    @Override
+    public String toString() {
+      StringBuilder buf = new StringBuilder(super.toString());
+      if (boundingBox.isValid()) {
+        buf.append(" bbox: ");
+        buf.append(boundingBox.toString());
+      }
+      if (geospatialTypes.isValid()) {
+        buf.append(" types: ");
+        buf.append(geospatialTypes.toString());
+      }
+      return buf.toString();
+    }
+
+    @Override
+    public BoundingBox getBoundingBox() {
+      return boundingBox;
+    }
+
+    @Override
+    public GeospatialTypes getGeospatialTypes() {
+      return geospatialTypes;
+    }
+
+    @Override
+    public boolean equals(Object o) {
+      if (this == o) {
+        return true;
+      }
+      if (!(o instanceof GeospatialStatisticsImpl that)) {
+        return false;
+      }
+      if (!super.equals(o)) {
+        return false;
+      }
+
+      return boundingBox.equals(that.boundingBox) &&
+              geospatialTypes.equals(that.geospatialTypes);
+    }
+
+    @Override
+    public int hashCode() {
+      final int prime = 31;
+      int result = super.hashCode();
+      result = prime * result + boundingBox.hashCode();
+      result = prime * result + geospatialTypes.hashCode();
+      return result;
+    }
+  }
+
   ColumnStatisticsImpl(OrcProto.ColumnStatistics stats) {
     if (stats.hasNumberOfValues()) {
       count = stats.getNumberOfValues();
@@ -1955,6 +2127,14 @@ public class ColumnStatisticsImpl implements ColumnStatistics {
     throw new UnsupportedOperationException("Can't update timestamp");
   }
 
+  public void updateGeometry(BytesWritable value) {
+    throw new UnsupportedOperationException("Can't update Geometry");
+  }
+
+  public void updateGeometry(byte[] bytes, int offset, int length) {
+    throw new UnsupportedOperationException("Can't update Geometry");
+  }
+
   public boolean isStatsExists() {
     return (count > 0 || hasNull == true);
   }
@@ -2046,6 +2226,9 @@ public class ColumnStatisticsImpl implements ColumnStatistics {
         return new TimestampInstantStatisticsImpl();
       case BINARY:
         return new BinaryStatisticsImpl();
+      case Geography:
+      case Geometry:
+        return new GeospatialStatisticsImpl();
       default:
         return new ColumnStatisticsImpl();
     }
@@ -2089,6 +2272,8 @@ public class ColumnStatisticsImpl implements ColumnStatistics {
                      writerUsedProlepticGregorian, convertToProlepticGregorian);
     } else if(stats.hasBinaryStatistics()) {
       return new BinaryStatisticsImpl(stats);
+    } else if (stats.hasGeospatialStatistics()) {
+      return new GeospatialStatisticsImpl(stats);
     } else {
       return new ColumnStatisticsImpl(stats);
     }
